@@ -8,9 +8,9 @@ import os
 import logging
 
 # validate, , validate things, internal
-from lib import validate
+from .lib import validate
 # CMakeGen, , generate build files, internal
-from lib import cmakegen
+from .lib import cmakegen
 
 
 def addOptions(parser):
